==> haskell-mmap-0.5.9-26-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
key:                  mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  46ce3aead8ae1faa238ce8114dcb2bce
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmap
hs-libraries:         HSmmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-27-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa
key:                  mmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  ce0335a8a7434d930ad0f372cf7df0a3
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmap-0.5.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmap
hs-libraries:         HSmmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
